@@ -7,21 +7,26 @@ use IO::File;
 use Geo::ShapeFile::Shape;
 use Config;
 use List::Util qw /min max/;
+use Scalar::Util qw/weaken/;
 use Tree::R;
 
 
-our $VERSION = '2.59_001';
+our $VERSION = '2.63_001';
 
 my $little_endian_sys = unpack 'b', (pack 'S', 1 );
 
 # Preloaded methods go here.
 sub new {
-    my $proto = shift;
-    my $class = ref($proto) || $proto;
+    my $proto    = shift;
+    my $filebase = shift || croak "Must specify filename!";
+    my $args     = shift || {};  #  should check it's a haashref
 
+    my $class = ref($proto) || $proto;
     my $self = {};
 
-    $self->{filebase} = shift || croak "Must specify filename!";
+    $self->{filebase} = $filebase;
+    #  should use a proper file name handler
+    #  so we can deal with fred.ext referring to fred.ext.shp
     $self->{filebase} =~ s/\.\w{3}$//;
 
     $self->{_enable_caching} = {
@@ -36,6 +41,12 @@ sub new {
 
     bless $self, $class;
 
+    #  control overall caching
+    if ($args->{no_cache}) {
+        $self->{_no_cache} = 1;
+    }
+
+    #  not sure what this does - possible residual from early plans
     $self->{_change_cache} = {
         shape_type => undef,
         records    => undef,
@@ -75,6 +86,17 @@ sub new {
     return $self;
 }
 
+sub _disable_all_caching {
+    my $self = shift;
+    #  a bit nuclear...
+    foreach my $type (qw/shp shx dbf shapes_in_area/) {
+        $self->{_enable_caching}{$type} = 0;
+        $self->{_object_cache} = {};
+        #$self->{_change_cache} = {};  #  need to work out what this is for
+    }
+    return;
+}
+
 sub caching {
     my $self = shift;
     my $what = shift;
@@ -88,6 +110,8 @@ sub caching {
 
 sub cache {
     my ($self, $type, $obj, $cache) = @_;
+    
+    return if $self->{_no_cache};
 
     return $self->{_change_cache}->{$type}->{$obj}
       if $self->{_change_cache}->{$type} && $self->{_change_cache}->{$type}->{$obj};
@@ -734,6 +758,8 @@ sub _get_handle {
         croak "Couldn't get file handle for $file: $!"
           if not $self->{$han}->open($file, O_RDONLY | O_BINARY);
         binmode $self->{$han}; # fix windows bug reported by Patrick Dughi
+        #  Maybe should handle explicitly in a destroy sub 
+        weaken $self->{han};
     }
 
     return $self->{$han};
@@ -838,12 +864,18 @@ Geo::ShapeFile - Perl extension for handling ESRI GIS Shapefiles.
 
   my $shapefile = Geo::ShapeFile->new('roads');
 
-  for(1 .. $shapefile->shapes()) {
-    my $shape = $shapefile->get_shp_record($_);
+  foreach my $id (1 .. $shapefile->shapes()) {
+    my $shape = $shapefile->get_shp_record($id);
     # see Geo::ShapeFile::Shape docs for what to do with $shape
 
-    my %db = $shapefile->get_dbf_record($_);
+    my %db = $shapefile->get_dbf_record($id);
   }
+  
+  #  As before, but do not cache any data.
+  #  Useful if you have large files and only need to access
+  #  each shape once or a small nmber of times.
+  my $shapefile = Geo::ShapeFile->new('roads', {no_cache => 1});
+
 
 =head1 ABSTRACT
 
@@ -862,14 +894,21 @@ base) formats.
 =over 4
 
 =item new ($filename_base)
+=item new ($filename_base, {no_cache => 1})
 
-Creates a new shapefile object, the only argument it takes is the basename
-for your data (don't include the extension, the module will automatically
+Creates a new shapefile object.  The first argument is the basename
+for your data (there is no need to include the extension, the module will automatically
 find the extensions it supports).  For example if you have data files called
 roads.shp, roads.shx, and roads.dbf, use 'Geo::ShapeFile->new("roads");' to
 create a new object, and the module will load the data it needs from the
 files as it needs it.
 
+The second (optional) argument is a hashref.
+Currently only no_cache is supported.
+If specified then data will not be cached in memory and the system will
+read from disk each time you access a shape.
+It will save memory for large files, though.
+
 =item type_is ($numeric_type)
 
 Returns true if the major type of this data file is the same as the type
