@@ -2,9 +2,9 @@ package Geo::ShapeFile::Point;
 # TODO - add dimension operators (to specify if 2 or 3 dimensional point)
 use strict;
 use warnings;
-use Math::Trig;
+use Math::Trig 1.04;
 use Carp;
-our $VERSION = '2.59_001';
+our $VERSION = '2.63_001';
 
 use overload
     '==' => 'eq',
